@@ -167,7 +167,9 @@ class Cia_table(Spectral_object):
         self.abs_coeff_unit=f['abs_coeff'].attrs['units']
         self.tgrid=f['t'][...]
         if 'cia_pair' in f:
-            self.mol1,self.mol2=f['cia_pair'][()].split('-')
+            tmp=f['cia_pair'][()]
+            if isinstance(tmp, bytes): tmp=tmp.decode('UTF-8')
+            self.mol1,self.mol2=tmp.split('-')
         elif 'cia_pair' in f.attrs:
             self.mol1,self.mol2=f.attrs['cia_pair'].split('-')
         f.close()  
