@@ -170,7 +170,7 @@ class Data_table(Spectral_object):
         self.convert_p_unit(p_unit='Pa')
 
     def interpolate_kdata(self, logp_array=None, t_array=None, x_array=1.,
-            log_interp=None, wngrid_limit=None):
+            log_interp=None, logp_interp=True, wngrid_limit=None):
         """interpolate_kdata interpolates the kdata at on a given temperature and
         log pressure profile. If a volume mixing ratio profile (`x_array`) is given,
         the cross section computed for the species is multiplied by `x_array` to account for the
@@ -213,7 +213,10 @@ class Data_table(Spectral_object):
         else:
             x_array=np.array([x_array])
         tind,tweight=interp_ind_weights(t_array,self.tgrid)
-        lpind,lpweight=interp_ind_weights(logp_array,self.logpgrid)
+        if logp_interp:
+            lpind,lpweight=interp_ind_weights(logp_array,self.logpgrid)
+        else:
+            lpind,lpweight=interp_ind_weights(10**logp_array,self.pgrid)
         if wngrid_limit is None:
             wngrid_filter = slice(None)
             Nw=self.Nw
@@ -458,7 +461,7 @@ class Data_table(Spectral_object):
         """Defines the "+" operator with another Data_table
 
         .. warning::
-            __radd__ is not implmented because we want to use the __add__ (or combine_with)
+            __radd__ is not implemented because we want to use the __add__ (or combine_with)
             method of the left object.
         """
         return self.combine_with(other)
@@ -495,6 +498,92 @@ class Data_table(Spectral_object):
         else:
             self.kdata=self.kdata[:,:,:,iw_min:iw_max]
 
+    def extend_spectral_range(self, wngrid_left=None, wngrid_right=None,
+            wnedges_left=None, wnedges_right=None,
+            remove_zeros=False):
+        """Extends the spectral range of an existing table (inplace).
+        The new bins are filled with zeros (except if remove_zeros=True)
+
+        Parameters
+        ----------
+            wngrid_left: array
+                Array of wavenumbers to add to the small wn end of the table.
+            wngrid_right: array
+                Array of wavenumbers to add to the high wn end of the table.
+
+        .. warning::
+            There should not be any overlap between wngrid_left, wngrid_right,
+            and the current wavenumber grid of the table. 
+
+        Other Parameters
+        ----------------
+            remove_zeros: bool (optional)
+                Whether zeros in the resulting table should be removed using
+                :func:`remove_zeros`.
+        """
+        new_wns=[]
+        new_wnedges=[]
+        idx_offset=0
+        if wngrid_left is not None:
+            wngrid_left=np.array(wngrid_left, dtype=float)
+            if wngrid_left[-1]>=self.wnedges[0]:
+                raise RuntimeError("The left grid overlaps with the current one")
+            new_wns.append(wngrid_left)
+            if wnedges_left is not None:
+                wnedges_left=np.array(wnedges_left, dtype=float)
+                new_wnedges.append(wnedges_left)
+            else:
+                new_wnedges.append([wngrid_left[0]])
+                new_wnedges.append(0.5*(wngrid_left[:-1]+wngrid_left[1:]))
+            idx_offset=wngrid_left.size
+        else:
+            if wnedges_left is not None:
+                if wnedges_left[-1]>=self.wnedges[0]:
+                    raise RuntimeError("The left grid overlaps with the current one")
+                wnedges_left=np.array(wnedges_left, dtype=float)
+                new_wnedges.append(wnedges_left)
+                new_wns.append(0.5*(wnedges_left[:-1]+wnedges_left[1:]))
+                new_wns.append([0.5*(wnedges_left[-1]+self.wnedges[0])])
+                idx_offset=wnedges_left.size
+
+        new_wns.append(self.wns)
+        new_wnedges.append(self.wnedges)
+        if wngrid_right is not None:
+            wngrid_right=np.array(wngrid_right, dtype=float)
+            if wngrid_right[0]<=self.wnedges[-1]:
+                raise RuntimeError("The right grid overlaps with the current one")
+            new_wns.append(wngrid_right)
+            if wnedges_right is not None:
+                wnedges_right=np.array(wnedges_right, dtype=float)
+                new_wnedges.append(wnedges_right)
+            else:
+                new_wnedges.append(0.5*(wngrid_right[:-1]+wngrid_right[1:]))
+                new_wnedges.append([wngrid_right[-1]])
+        else:
+            if wnedges_right is not None:
+                wnedges_right=np.array(wnedges_right, dtype=float)
+                if wnedges_right[0]<=self.wnedges[-1]:
+                    raise RuntimeError("The right grid overlaps with the current one")
+                new_wnedges.append(wnedges_right)
+                new_wns.append([0.5*(wnedges_right[0]+self.wnedges[-1])])
+                new_wns.append(0.5*(wnedges_right[:-1]+wnedges_right[1:]))
+        new_wns=np.concatenate(new_wns)
+        new_wnedges=np.concatenate(new_wnedges)
+        newshape=self.shape
+        if self.Nx is None:
+            newshape[2]=new_wns.size
+            newkdata=np.zeros(newshape)
+            newkdata[:,:,idx_offset:idx_offset+self.Nw]=self.kdata
+        else:
+            newshape[3]=new_wns.size
+            newkdata=np.zeros(newshape)
+            newkdata[:,:,:,idx_offset:idx_offset+self.Nw]=self.kdata
+        self.kdata=newkdata
+        self.wns=new_wns
+        self.wnedges=new_wnedges
+        self.Nw=self.wns.size
+        if remove_zeros : self.remove_zeros(deltalog_min_value=10.)
+
     def bin_down_cp(self, wnedges=None, **kwargs):
         """Creates a copy of the instance and bins it down using the methods in 
         Ktable or Xtable.
@@ -537,7 +626,7 @@ class Data_table(Spectral_object):
             f: h5py file instance
                 The file to write that is created in daughter classes
         """
-        dt = h5py.special_dtype(vlen=str)
+        dt = h5py.string_dtype(encoding='utf-8')
         f.create_dataset("DOI", (1,), data=self.DOI, dtype=dt)
         f.create_dataset("Date_ID", (1,), data=self.Date_ID, dtype=dt)
         f.create_dataset("mol_name", (1,), data=self.mol, dtype=dt)
@@ -556,9 +645,6 @@ class Data_table(Spectral_object):
                 compression=compression, compression_opts=compression_level)
             f["p"].attrs["units"] = self.p_unit
 
-        f.create_dataset("bin_edges", data=self.wnedges,
-            compression=compression, compression_opts=compression_level)
-
         f.create_dataset("wnrange", data=self.wnrange,
             compression=compression, compression_opts=compression_level)
         f.create_dataset("wlrange", data=self.wlrange,
