@@ -174,9 +174,11 @@ class Gas_mix(Spectral_object):
             self.Ng=self.kdatabase.Ng
             if self.kdatabase.p_unit != 'Pa' or rm_molec(self.kdatabase.kdata_unit) != 'm^2':
                 print("""You're being Bad!!! You are trying *NOT* to use MKS units!!!
-                You can convert to mks using convert_to_mks.
+                You can convert to mks using convert_to_mks on your Kdatabase.
                 More generally, you can specify exo_k.Settings().set_mks(True) 
-                to force automatic conversion to mks for all newly loaded data.
+                to set MKS system as default for all newly loaded data,
+                but beware that this global setting is overridden by local options
+                specified during the loading.
                 You will have to reload all your data though.
                 (A good thing it does not take so long). """)
                 raise RuntimeError("Bad units in the Kdatabase used with Gas_mix.")
@@ -198,11 +200,14 @@ class Gas_mix(Spectral_object):
         if self.cia_database is not None:
             if self.cia_database.abs_coeff_unit != 'm^5':
                 print("""You're being Bad!!! You are trying *NOT* to use MKS units!!!
-                You can convert to mks using convert_to_mks.
+                You can convert to mks using convert_to_mks on your CIAdatabase.
                 More generally, you can specify exo_k.Settings().set_mks(True) 
-                to force automatic conversion to mks of all newly loaded data.
+                to set MKS system as default for all newly loaded data,
+                but beware that this global setting is overridden by local options
+                specified during the loading.
                 You will have to reload all your data though.
                 (A good thing it does not take so long). """)
+
                 raise RuntimeError("Bad units in the CIAdatabase used with Gas_mix.")
 
     def _compute_spectral_range(self, wn_range=None, wl_range=None):
@@ -259,7 +264,7 @@ class Gas_mix(Spectral_object):
 
     def cross_section(self, composition=None, logp_array=None, t_array=None,
             wl_range=None, wn_range=None, rayleigh=True,
-            write=0, random_overlap=False, **kwargs):
+            write=0, random_overlap=False, logp_interp=True, **kwargs):
         """Computes the cross section (m^2/total number of molecule) for the mix
         at each of the logPT points as a function of wavenumber (and possibly g point).
 
@@ -324,6 +329,7 @@ class Gas_mix(Spectral_object):
         for mol in mol_to_be_done:
             tmp_kdata=self.kdatabase[mol].interpolate_kdata(logp_array=self.logp_array,
                 t_array=self.t_array, x_array=vmr_prof[mol], wngrid_limit=local_wn_range,
+                logp_interp=logp_interp,
                 **kwargs)
             if first_mol:
                 kdata_array=tmp_kdata
