@@ -8,8 +8,9 @@ from .xtable import Xtable
 from .gas_mix import Gas_mix
 from .settings import Settings
 from .util.interp import rm_molec
+from .util.spectral_object import Spectral_object
 
-class Kdatabase(object):
+class Kdatabase(Spectral_object):
     """This object contains mainly a dictionary of individual :class:`~exo_k.ktable.Ktable`
     or :class:`~exo_k.xtable.Xtable` objects for each molecule. 
 
@@ -39,7 +40,12 @@ class Kdatabase(object):
 
         >>> Kdatabase(None)
 
-        Loads an empty database to be filled later.
+        Loads an empty database to be filled later with
+        :func:`~exo_k.kdatabase.Kdatabase.add_ktables`.
+
+        .. important::
+            By default, Ktables have zeros removed when loaded to avoid log interpolation
+            issues. You can avoid that with the `remove_zeros=False` keyword.
         """
         self.ktables={}
         self._settings=Settings()
@@ -74,7 +80,7 @@ class Kdatabase(object):
         
     def add_ktables(self, *ktables):
         """Adds as many :class:`~exo_k.ktable.Ktable` or :class:`~exo_k.xtable.Xtable`
-        to the database as you want.
+        to the database as you want (inplace).
 
         Parameters
         ----------
@@ -114,10 +120,12 @@ class Kdatabase(object):
                         You'll need to use convert_kdata_unit""")
                     self.consolidated_kdata_unit=False
                 self.ktables[tmp_ktable.mol]=tmp_ktable
-                if not np.array_equal(tmp_ktable.wns,self.wns):
+                if (((self.Ng is None) and not np.array_equal(tmp_ktable.wns,self.wns)) or \
+                  ((self.Ng is not None) and not np.array_equal(tmp_ktable.wnedges,self.wnedges))):
+                  # If Xtables, compare wns. If Ktables, compare wnedges
                     self.consolidated_wn_grid=False
                     print("""Carefull, not all tables have the same wevelength grid.
-                        You'll need to use bin_down""")
+                        You'll need to use bin_down (Ktable) or sample (Xtable)""")
                     self.wns    = None
                     self.wnedges= None
                     self.Nw     = None
@@ -179,21 +187,9 @@ class Kdatabase(object):
             raise KeyError('The requested molecule is not available.')
         return self.ktables[molecule]
 
-    @property
-    def wls(self):
-        """Returns the wavelength array for the bin centers
-        """
-        return 10000./self.wns
-
-    @property
-    def wledges(self):
-        """Returns the wavelength array for the bin edges
-        """
-        return 10000./self.wnedges
-
     def remap_logPT(self, logp_array=None, t_array=None):
-        """Applies the bin_down method to all the tables in the database. This can be used 
-        to put all the tables onthe same PT grid.
+        """Applies the remap_logPT method to all the tables in the database (inplace).
+        This can be used to put all the tables onthe same PT grid.
 
         See :func:`exo_k.data_table.Data_table.remap_logPT` for details.
         """
@@ -210,8 +206,8 @@ class Kdatabase(object):
         self.consolidated_PT_grid=True
 
     def bin_down(self, wnedges=None, **kwargs):
-        """Applies the bin_down method to all the tables in the database. This can be used 
-        to put all the tables onthe same wavenumber grid.
+        """Applies the bin_down method to all the tables in the database (inplace).
+        This can be used to put all the tables on the same wavenumber grid.
 
         See :func:`exo_k.ktable.Ktable.bin_down` or :func:`exo_k.xtable.Xtable.bin_down`
         for details.
@@ -246,8 +242,8 @@ class Kdatabase(object):
         return res
 
     def sample(self, wngrid, **kwargs):
-        """Applies the bin_down method to all the tables in the database. This can be used 
-        to put all the tables onthe same wavenumber grid.
+        """Applies the sample method to all the tables in the database (inplace).
+        This can be used to put all the tables onthe same wavenumber grid.
 
         See Ktable.bin_down() or Xtable.bin_down() for details.
         """
@@ -279,7 +275,7 @@ class Kdatabase(object):
         return res
 
     def clip_spectral_range(self, wn_range=None, wl_range=None):
-        """Limits the data to the provided spectral range:
+        """Limits the data to the provided spectral range (inplace):
 
            * Wavenumber in cm^-1 if using wn_range argument
            * Wavelength in micron if using wl_range
@@ -293,7 +289,7 @@ class Kdatabase(object):
                 self.Nw=self.ktables[mol].Nw
 
     def convert_p_unit(self, p_unit='unspecified'):
-        """Converts pressure unit of all Data_tables.
+        """Converts pressure unit of all Data_tables (inplace).
         See Data_table.convert_p_unit() for details.
         """
         first=True
@@ -304,7 +300,7 @@ class Kdatabase(object):
         self.consolidated_p_unit=True
 
     def convert_kdata_unit(self, kdata_unit='unspecified'):
-        """Converts kdata unit of all Data_tables.
+        """Converts kdata unit of all Data_tables (inplace).
         See Data_table.convert_kdata_unit() for details.
         """
         first=True
@@ -315,7 +311,7 @@ class Kdatabase(object):
         self.consolidated_kdata_unit=True
 
     def convert_to_mks(self):
-        """Converts units of all `Data_table`s to MKS
+        """Converts units of all `Data_table`s to MKS (inplace)
         """
         first=True
         for mol in self.molecules:
@@ -327,7 +323,10 @@ class Kdatabase(object):
         self.consolidated_kdata_unit=True
 
     def create_mix_ktable(self, composition, inactive_species=[]):
-        """creates the kdata table for a mix of molecules.
+        """Creates a :class:`~exo_k.ktable.Ktable`
+        for a mix of molecules.
+
+        The table is computed over the P,T grid of the `Kdatabase` instance. 
 
         Parameters
         ----------
@@ -337,7 +336,8 @@ class Kdatabase(object):
                 with shape (pgrid.size,tgrid.size).
                 This composition will instantiate a :class:`Gas_mix` object.
                 In particular, if a value is 'background', this gas will
-                be used to fill up to sum(vmr)=1 (See chemistry.gas_type for details).
+                be used to fill up to sum(vmr)=1 (See :class:`~exo_k.gas_mix.Gas_mix`
+                for details).
                 For each (P,T) point, the sum of all the mixing ratios
                 should be lower or equal to 1.
                 If it is lower, it is assumed that the rest of the gas is transparent.
@@ -347,8 +347,8 @@ class Kdatabase(object):
 
         Returns
         -------
-            Ktable object
-                A new ktable for the mix
+            :class:`~exo_k.ktable.Ktable` object
+                A new ktable for the mix.
         """
         if self.Ng is None: raise RuntimeError( \
             """Create_mix_ktable cannot work with a database of cross sections.
@@ -367,13 +367,6 @@ class Kdatabase(object):
             You should probably use convert_kdata_unit().""")
         mol_to_be_done=set(composition.keys())
         mol_to_be_done=mol_to_be_done-set(inactive_species)
-        if not mol_to_be_done:
-            print("""You are creating a mix without any active gas:
-                This will be awfully transparent""")
-            res=self[self.molecules[0]].copy(cp_kdata=False)
-            res.kdata=np.zeros(res.shape)
-            return res
-        gas_mixture=Gas_mix(composition)
         if all(elem in self.molecules for elem in mol_to_be_done):
             print('I have all the requested molecules in my database')
             print(mol_to_be_done)
@@ -381,6 +374,13 @@ class Kdatabase(object):
             print('Do not have all the molecules in my database')
             mol_to_be_done=mol_to_be_done.intersection(set(self.molecules))
             print('Molecules to be treated: ', mol_to_be_done)
+        if not mol_to_be_done:
+            print("""You are creating a mix without any active gas:
+                This will be awfully transparent""")
+            res=self[self.molecules[0]].copy(cp_kdata=False)
+            res.kdata=np.zeros(res.shape)
+            return res
+        gas_mixture=Gas_mix(composition)
         first_mol=True
         for mol in mol_to_be_done:
             if first_mol:
@@ -406,18 +406,21 @@ class Kdatabase(object):
         """Creates a Ktable5d for a mix of molecules with a variable gas.
         In essence, the regular create_mix_ktable is called to create
         two mixes:
-        * The background mix specified by composition=bg_comp, inactive_species=bg_inac_species
-        * The variable gas specified by composition=vgas_comp, inactive_species=vgas_inac_species
 
-        See create_mix_ktable for details.
+          * The background mix specified by composition=bg_comp,
+            inactive_species=bg_inac_species
+          * The variable gas specified by composition=vgas_comp,
+            inactive_species=vgas_inac_species
+
+        See :func:`create_mix_ktable` for details.
 
         These two gases are then mixed together for an array of vmr x_array where
         var_gas has a vmr of x_array and the background gas has a vmr of 1.-x_array
 
         Returns
         -------
-            Ktable5d object
-                A new ktable for the mix
+            :class:`~exo_k.ktable5d.Ktable5d` object
+                A new ktable for the mix with a dimension for the vmr of the variable gas.
         """
         if x_array is None:
             raise RuntimeError('x_array is None: pas bien!!!')
