@@ -107,10 +107,14 @@ class Ktable5d(Data_table):
                 else:
                     self.mol=os.path.basename(filename).split(self._settings._delimiter)[0]
             if isinstance(self.mol, np.ndarray): self.mol=self.mol[0]
+            if isinstance(self.mol, bytes): self.mol=self.mol.decode('UTF-8')
             if 'method' in f:
                 self.sampling_method=f['method'][()][0]
+                if isinstance(self.sampling_method, bytes):
+                    self.sampling_method=self.sampling_method.decode('UTF-8')
             if 'DOI' in f:
                 self.DOI=f['DOI'][()][0]
+                if isinstance(self.DOI, bytes): self.DOI=self.DOI.decode('UTF-8')
             self.wns=f['bin_centers'][...]
             self.wnedges=f['bin_edges'][...]
             if 'units' in f['bin_edges'].attrs:
@@ -144,7 +148,7 @@ class Ktable5d(Data_table):
             filename: str
                 Name of the file to be created and saved
         """
-        dt = h5py.special_dtype(vlen=str)
+        dt = h5py.string_dtype(encoding='utf-8')
         fullfilename=filename
         if not filename.lower().endswith(('.hdf5', '.h5')):
             fullfilename=filename+'.h5'
@@ -170,6 +174,8 @@ class Ktable5d(Data_table):
             f.create_dataset("ngauss", data=self.Ng)
             f.create_dataset("bin_centers", data=self.wns,
                 compression=compression, compression_opts=compression_level)
+            f.create_dataset("bin_edges", data=self.wnedges,
+                compression=compression, compression_opts=compression_level)
 
             # where most of the data is actually written
             self.write_hdf5_common(f, compression=compression, compression_level=compression_level,
@@ -473,6 +479,10 @@ class Ktable5d(Data_table):
             array of shape (logp_array.size, self.Nw , self.Ng)
                 The interpolated kdata.
         """
+        #clipping data
+        logp_array=np.clip(logp_array, self.logpgrid[0], self.logpgrid[-1])
+        t_array=np.clip(t_array, self.tgrid[0], self.tgrid[-1])
+        x_array=np.clip(x_array, self.xgrid[0], self.xgrid[-1])
         coord_to_interp=np.array([logp_array,t_array,np.log(x_array)]).transpose()
         tmp_res=self._finterp_kdata(coord_to_interp)
         if wngrid_limit is None:
@@ -504,6 +514,10 @@ class Ktable5d(Data_table):
         is controlled by self._settings._log_interp but only when the ktable is loaded.
         If you change that after the loading, you should rerun setup_interpolation().
         """
+        #clipping data
+        logp_array=np.clip(logp_array, self.logpgrid[0], self.logpgrid[-1])
+        t_array=np.clip(t_array, self.tgrid[0], self.tgrid[-1])
+        x_array=np.clip(x_array, self.xgrid[0], self.xgrid[-1])
         coord=np.array(np.meshgrid(logp_array, t_array, np.log(x_array))).transpose((2,1,3,0))
         if self._local_log_interp:
             tmp_res=np.exp(self._finterp_kdata(coord))
@@ -726,6 +740,16 @@ class Ktable5d(Data_table):
         if self.kdata is not None:
             self.setup_interpolation()
 
+    def extend_spectral_range(self, **kwargs):
+        """Extends the spectral range of an existing table (inplace).
+        The new bins are filled with zeros (except if remove_zeros=True).
+
+        See :func:`exo_k.data_table.Data_table.extend_spectral_range` method for details
+        on the arguments and options.
+        """
+        super().extend_spectral_range(**kwargs)
+        self.setup_interpolation()
+
     def remap_g(self, ggrid=None, weights=None):
         """Method to resample a kcoeff table to a new g grid (inplace).
 
