@@ -88,8 +88,10 @@ class Xtable(Data_table):
                 else:
                     self.mol=os.path.basename(filename).split(self._settings._delimiter)[0]
             if isinstance(self.mol, np.ndarray): self.mol=self.mol[0]
+            if isinstance(self.mol, bytes): self.mol=self.mol.decode('UTF-8')
             if 'DOI' in f:
                 self.DOI=f['DOI'][()][0]
+                if isinstance(self.DOI, bytes): self.DOI=self.DOI.decode('UTF-8')
             if 'bin_edges' in f:
                 self.wns=f['bin_edges'][...]
                 if 'units' in f['bin_edges'].attrs:
@@ -141,6 +143,8 @@ class Xtable(Data_table):
                 f.create_dataset("xsecarr", data=self.kdata, compression=compression,
                     compression_opts=compression_level)
                 f["xsecarr"].attrs["units"] = self.kdata_unit
+            f.create_dataset("bin_edges", data=self.wns,
+                compression=compression, compression_opts=compression_level)
 
             # where most of the data is actually written
             self.write_hdf5_common(f, compression=compression, compression_level=compression_level,
